@@ -41,6 +41,7 @@ from ..utils import is_index_like as dask_is_index_like
 
 # register pandas extension types
 from . import _dtypes  # noqa: F401
+from . import methods
 
 
 def is_integer_na_dtype(t):
@@ -646,7 +647,7 @@ def check_meta(x, meta, funcname=None, numeric_equal=True):
     elif is_dataframe_like(meta):
         dtypes = pd.concat([x.dtypes, meta.dtypes], axis=1, sort=True)
         bad_dtypes = [
-            (col, a, b)
+            (repr(col), a, b)
             for col, a, b in dtypes.fillna("-").itertuples()
             if not equal_dtypes(a, b)
         ]
@@ -675,8 +676,8 @@ def check_meta(x, meta, funcname=None, numeric_equal=True):
 def check_matching_columns(meta, actual):
     # Need nan_to_num otherwise nan comparison gives False
     if not np.array_equal(np.nan_to_num(meta.columns), np.nan_to_num(actual.columns)):
-        extra = actual.columns.difference(meta.columns).tolist()
-        missing = meta.columns.difference(actual.columns).tolist()
+        extra = methods.tolist(actual.columns.difference(meta.columns))
+        missing = methods.tolist(meta.columns.difference(actual.columns))
         if extra or missing:
             extra_info = f"  Extra:   {extra}\n  Missing: {missing}"
         else:
@@ -775,7 +776,7 @@ def _maybe_sort(a):
                 a.index.names = [
                     "-overlapped-index-name-%d" % i for i in range(len(a.index.names))
                 ]
-            a = a.sort_values(by=a.columns.tolist())
+            a = a.sort_values(by=methods.tolist(a.columns))
         else:
             a = a.sort_values()
     except (TypeError, IndexError, ValueError):
